==> vokoscreen_2.0.16~beta.orig.tar.gz: vokoscreen-2.0.16-beta/language/vokoscreen_es_ES.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es_ES" version="2.0">
<context>
    <name>QvkMail</name>
    <message>
        <source>Mail last Video</source>
        <translation>Envia por email el último vídeo</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>Enviar a uno o más vídeos seleccionados</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Enviar</translation>
    </message>
    <message>
        <source>You find the Video as attachment</source>
        <translation>Puedes encontrar el vídeo como archivo adjunto</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>Seleccione uno o más archivos</translation>
    </message>
</context>
<context>
    <name>QvkWebcamController</name>
    <message>
        <source>is busy</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QvkWebcamWindow</name>
    <message>
        <source>Noborder</source>
        <translation>Sin borde</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Borde</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>pantalla</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>ventana</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>área</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Lupa</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Predeterminado</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Codec</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>No grabar el cursor del ratón</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Ubicación del vídeo</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Reproductor</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>Minimizar Vokoscreen al comenzar la grabación</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>iniciar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>detener</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Reproducir</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Enviar</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>Tiempo de grabación</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>Tamaño en KB</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>Tamaño de la pantalla a grabar</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>Ajustes fps</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Abrir directorio</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Cuenta regresiva</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>Reproducir último vídeo</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>Enviar vídeo</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation>Seleccione uno o más dispositivos</translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation>Fotogramas por segundo actuales</translation>
    </message>
    <message>
        <source>Device %1 is busy</source>
        <translation>El dispositivo %1 está ocupado</translation>
    </message>
    <message>
        <source>Go</source>
        <translation>iniciar</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mailinglist</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Support</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Developer</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Frames</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Beta openSUSE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Beta Ubuntu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Donate</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Program for recording</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Translations</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show in systray</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>New version available</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Videocodec</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Webcam</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mirrored</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> vokoscreen_2.1.8~beta.orig.tar.gz: vokoscreen-2.1.8-beta/language/vokoscreen_es_ES.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es_ES" version="2.0">
<context>
    <name>AlsaBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>El dispositivo está ocupado</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Used by</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <source>Dialog</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please install a videoplayer</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MailDialog</name>
    <message>
        <source>Mail last Video</source>
        <translation>Envia por email el último vídeo</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>Enviar a uno o más vídeos seleccionados</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Enviar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QvkMail</name>
    <message>
        <source>You find the Video as attachment</source>
        <translation>Puedes encontrar el vídeo como archivo adjunto</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>Seleccione uno o más archivos</translation>
    </message>
</context>
<context>
    <name>QvkWebcamWindow</name>
    <message>
        <source>Border</source>
        <translation>Borde</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <source>Show over fullscreen</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>WebcamBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>El dispositivo está ocupado</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Used by</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>pantalla</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>ventana</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>área</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Lupa</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Predeterminado</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Codec</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>No grabar el cursor del ratón</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Ubicación del vídeo</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Reproductor</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>Minimizar Vokoscreen al comenzar la grabación</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>iniciar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>detener</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Reproducir</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Enviar</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>Tiempo de grabación</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>Tamaño en KB</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>Tamaño de la pantalla a grabar</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>Ajustes fps</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Abrir directorio</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Cuenta regresiva</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>Reproducir último vídeo</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>Enviar vídeo</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation>Seleccione uno o más dispositivos</translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation>Fotogramas por segundo actuales</translation>
    </message>
    <message>
        <source>Go</source>
        <translation>iniciar</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mailinglist</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Support</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Developer</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Frames</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Donate</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Program for recording</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Translations</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show in systray</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>New version available</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Videocodec</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Webcam</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mirrored</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Display</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>All Displays</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Developer Homepage</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
